---
title: Howto Ansible/Cisco : automatisation d'infrastructure
categories automation
---

* Documentation : <http://docs.ansible.com/ansible/latest/list_of_network_modules.html#ios>

Cette documentation est basée sur la version 2.2 d'Ansible que nous utilisons actuellement, et est susceptible de différer dès la version 2.3.

# Connection aux switchs

Ansible utilise python, mais ce dernier n'étant pas disponible sur les switchs, le mode de connexion n'est pas le même. Au lieu d'utiliser une connexion SSH, on doit utiliser une connexion locale : Ansible exécute le code sur la machine locale, ce qui génère les commandes qui sont ensuite envoyées par SSH sur le switch distant. Cela pose cependant un problème : le switch sur lequel on veut lancer un playbook doit être directement accessible par la machine locale, puisque le fichier ~/.ssh/config n'est pas utilisé.

On doit donc indiquer dans notre playbook comment la machine locale doit se connecter sur le switch distant dans une variable qui sera ensuite passée à chaque utilisation d'un module.

Le mode de récupération des facts par défaut d'Ansible ne fonctionne également pas, il faut le désactiver. Un module spécifique lui est dédié.

~~~{.yaml}
- hosts: switchs
  gather_facts: no
  connection: local

  vars:
    provider:
      host: "{{ inventory_hostname }}"
      username: "{{ ansible_user }}"
      password: "{{ ansible_ssh_pass }}"

  roles:
    - role-name
~~~

Le nom dans l'inventory doit alors correspondre au nom utilisé pour se connecter au switch. Si aucun hostname ne lui est associé, son IP doit être utilisée. Si l'on veut quand même utiliser un nom d'hôte sous forme d'alias, une variable doit être définie dans le fichier d'inventory :

~~~
[switchs]
SW01 SWITCH_IP=192.0.2.1
~~~

Et cette variable doit être utilisée dans le playbook :

~~~{.yaml}
  vars:
    provider:
      host: "{{ SWITCH_IP }}"
      username: "{{ ansible_user }}"
      password: "{{ ansible_ssh_pass }}"
~~~

Ainsi, on peut choisir sur quelle machine lancer le playbook avec le nom défini dans l'inventory.

# Modules